import request from '@/utils/request'
// 新增级别
export function levelAdd(data) {
	return request({
		url: '/system/level',
		method: 'post',
		data
	})
}
//查询级别
export function levelList() {
	return request({
		url: '/system/level/list',
		method: 'get'
	})
}
//修改级别
export function levelUpd(data) {
	return request({
		url: '/system/level',
		method: 'put',
		data
	})
}
//删除级别
export function levelDel(data) {
	return request({
		url: `/system/level/${data}`,
		method: 'delete'
	})
}

//级别上升下降排序
export function levelOrder(data) {
	return request({
		url: '/system/level/updateSort',
		method: 'put',
		data
	})
}

//新增职务
export function postAdd(data) {
	return request({
		url: '/system/job',
		method: 'post',
		data
	})
}
//查询职务
export function postList(params) {
	return request({
		url: '/system/job/list',
		method: 'get',
		params
	})
}
//修改职务
export function postUpd(data) {
	return request({
		url: '/system/job',
		method: 'put',
		data
	})
}
//删除职务
export function postDel(data) {
	return request({
		url: `/system/job/${data}`,
		method: 'delete'
	})
}

//职务上升下降排序
export function postOrder(data) {
	return request({
		url: '/system/job/updateSort',
		method: 'put',
		data
	})
}
